Stanza Matchers
===============

The Basic Matcher
-----------------
.. module:: sleekxmpp.xmlstream.matcher.base

.. autoclass:: MatcherBase
    :members:


ID Matching
-----------
.. module:: sleekxmpp.xmlstream.matcher.id

.. autoclass:: MatcherId
    :members:


Stanza Path Matching
--------------------
.. module:: sleekxmpp.xmlstream.matcher.stanzapath

.. autoclass:: StanzaPath
    :members:


XPath
-----
.. module:: sleekxmpp.xmlstream.matcher.xpath

.. autoclass:: MatchXPath
    :members:


XMLMask
-------
.. module:: sleekxmpp.xmlstream.matcher.xmlmask

.. autoclass:: MatchXMLMask
    :members:
